ReactionsDialogWidget class
A dialog widget that displays reactions and context menu options for a message.
This widget creates a modal dialog with three main sections:
- A row of reaction emojis that can be tapped
- The original message (displayed using a Hero animation)
- A context menu with customizable options
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- ReactionsDialogWidget
Constructors
- ReactionsDialogWidget({Key? key, required String messageId, required Widget messageWidget, required ReactionsController controller, required ChatReactionsConfig config, required dynamic onReactionTap(String), required dynamic onMenuItemTap(MenuItem), Alignment alignment = Alignment.centerRight})
-
Creates a reactions dialog widget.
const
Properties
- alignment → Alignment
-
Alignment of the dialog components.
final
- config → ChatReactionsConfig
-
Configuration for the reactions dialog.
final
- controller → ReactionsController
-
Controller to manage reaction state.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- messageId → String
-
Unique identifier for the hero animation.
final
- messageWidget → Widget
-
The widget displaying the message content.
final
- onMenuItemTap → dynamic Function(MenuItem)
-
Callback triggered when a context menu item is selected.
final
- onReactionTap → dynamic Function(String)
-
Callback triggered when a reaction is selected.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited